### Muleta et al. G3 "Evaluating genomic selection for small breeding programs in developing countries"
### Description: Sequences of founder populations were simulated using the program MaCS (Chen et al., 2008) implemented in AlphaSimR.
### Base population was created by intermating the founder population several generation and used as C0 population as well as training population
### Recurrent selection was initiated by selecting top indviduals from the C0 family based on phenotpes, which was intermated to create next cycle breeding population
rm(list = ls())
library(AlphaSimR)
################################################################
# Define parentl and breeding population sizes for GARS and PRS   
################################################################
Ne_Par5 <- 5; Ne_Pop50 <- 50; Ne_Par20 <- 20; Ne_Pop200 <- 200; Ne_Par100 <- 100; Ne_Pop1000 <- 1000; Ne_Par200 <- 200;
Ne_Pop2000 <- 2000; Ne_Pop500_lim <- 500; Ne_Pop500_lim <- 500; Ne_Par5_pheno <- 5; Ne_Pop50_pheno <- 50; Ne_Par20_pheno <- 20
Ne_Pop200_pheno <- 200; Ne_Par100_pheno <- 100; Ne_Pop1000_pheno <- 1000; Ne_Par200_pheno <- 200; Ne_Pop2000_pheno <- 2000

################################################################
## Define parameters for trait genetic architecture ###########  
################################################################
trait1=1; trainSize = 400; nProgeny = 1
nInd=20; nChr = 10; segSites = 10000; maxQtl=1000; maxSnp=9000; minSnpFreq = 0.01
nQtlPerChr_olig = 5; meanG_olig=c(0,0); varG_olig=c(0.7,0.7); varEnv_olig=c(0.05,0.05); varGE_olig =c(0.15,0.15); corr_olig =matrix(c(1,0.99,0.99,1),nrow=2); corrGxe_olig =matrix(c(1,0.99,0.99,1),nrow=2)
VarE_olig = c(0.1, 0.1); reps = 3; w = 0.5; nProgeny = 1; selIndex = selIndex(Y =matrix(c(1,2),nrow=1), b=c(0.9,0.1), scale = FALSE)
nQtlPerChr_poly=50; meanG_poly=c(0,0); varG_poly=c(0.3,0.3); varEnv_poly=c(0.1,0.1); varGE_poly = c(0.3,0.3); corr_poly = matrix(c(1,0.99,0.99,1), nrow=2); corrGxe_poly = matrix(c(1,0.99,0.99,1), nrow=2); varE_poly = c(0.3, 0.3)
shape = 1; Ne=20; whichTrait = 1; nruns <- 1; df_mat <- data.frame()
####################################################################
## Simulate founder population and add trait #######################
#################################################################### 
for (k in 1: nruns){
  FOUNDERPOP = runMacs(nInd=nInd,nChr=nChr,segSites=segSites,
                       inbred=TRUE,manualCommand = paste(
                         "1000000000 -t", #Physical lenght 1e8 base pairs
                         2.5/1E8*(4*Ne), #Mutation rate adjusted for Ne
                         "-r",1/1E8*(4*Ne), #Recombination rate adjusted for Ne
                         "-eN",10/(4*Ne),100/Ne), #Modeling Ne=100 at 10 generations ago
                       manualGenLen=2) #Genetic length 1 Morgan
  SIMPARAM = createSimulation(FOUNDERPOP,maxQtl=maxQtl,maxSnp=maxSnp, minSnpFreq = minSnpFreq, snpQtlOverlap=FALSE, gender="no", recombRatio = 1)
  SIMPARAM =addTraitAG(FOUNDERPOP, nQtlPerChr=nQtlPerChr_olig, meanG=meanG_olig, varG=varG_olig, varEnv=varEnv_olig, varGE = varGE_olig, corr = corr_olig, corrGxe = corrGxe_olig, gamma = FALSE, shape = shape, simParam = NULL)
  #SIMPARAM =addTraitAG(FOUNDERPOP, nQtlPerChr=nQtlPerChr_poly, meanG=meanG_poly, varG=varG_poly, varEnv=varEnv_poly, varGE =varGE_poly, corr = corr_poly, corrGxe = corrGxe_poly, gamma = FALSE, shape = shape, simParam = NULL)
  SIMPARAM = addSnpChip(1000)
  ###############################################################################################################
  ## Base/Trainning population
  ################################################################################################################
  train_pop2 = newPop(FOUNDERPOP)
  unlink("GS1",recursive=TRUE)
  dir.create("GS1")
  writeRecords(train_pop2,"GS1",trait1)
  for(gen in 1:5){
    train_pop2 = randCross(train_pop2,trainSize)
    writeRecords(train_pop2,"GS1",trait1)
  }
  unlink("GS",recursive=TRUE)
  dir.create("GS")
  for(gen in 1:5){
    train_pop1 = self(train_pop2, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
    writeRecords(train_pop1,"GS",trait1)
  }
  #####################################################################################
  #######Population size (number of parents) selected to be recombined = 5 ############
  #####################################################################################
  
  train_pop <- setPheno(train_pop1,varE = VarE_olig, reps = reps,w=w) # w is the p-value for the environmental covariate
  q5p5_bestInd1=selectInd(train_pop, Ne_Par5, trait = trait1, use = "gv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop1 = randCross(q5p5_bestInd1, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  gsModel = RRBLUP("GS",whichTrait,use="GV")
  q5p5_pop1 = setEBV(q5p5_pop1,gsModel)
  q5p5_pa1=cor(q5p5_pop1@gv[,whichTrait],q5p5_pop1@ebv[,whichTrait])
  
  q5p5_bestInd2=selectInd(q5p5_pop1, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop2 = randCross(q5p5_bestInd2, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop2 = setEBV(q5p5_pop2,gsModel)
  q5p5_pa2=cor(q5p5_pop2@gv[,whichTrait],q5p5_pop2@ebv[,whichTrait])
  
  q5p5_bestInd3=selectInd(q5p5_pop2, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop3 = randCross(q5p5_bestInd3, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop3 = setEBV(q5p5_pop3,gsModel)
  q5p5_pa3=cor(q5p5_pop3@gv[,whichTrait],q5p5_pop3@ebv[,whichTrait])
  
  q5p5_bestInd4=selectInd(q5p5_pop3, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop4 = randCross(q5p5_bestInd4, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop4 = setEBV(q5p5_pop4,gsModel)
  q5p5_pa4=cor(q5p5_pop4@gv[,whichTrait],q5p5_pop4@ebv[,whichTrait])
  q5p5_bestInd5=selectInd(q5p5_pop4, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop5 = randCross(q5p5_bestInd5, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop5 = setEBV(q5p5_pop5,gsModel)
  q5p5_pa5=cor(q5p5_pop5@gv[,whichTrait],q5p5_pop5@ebv[,whichTrait])
  q5p5_bestInd6=selectInd(q5p5_pop5, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop6 = randCross(q5p5_bestInd6, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop6 = setEBV(q5p5_pop6,gsModel)
  q5p5_pa6=cor(q5p5_pop6@gv[,whichTrait],q5p5_pop6@ebv[,whichTrait])
  q5p5_bestInd7=selectInd(q5p5_pop6, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop7 = randCross(q5p5_bestInd7, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop7 = setEBV(q5p5_pop7,gsModel)
  q5p5_pa7=cor(q5p5_pop7@gv[,whichTrait],q5p5_pop7@ebv[,whichTrait])
  q5p5_bestInd8=selectInd(q5p5_pop7, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop8 = randCross(q5p5_bestInd8, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop8 = setEBV(q5p5_pop8,gsModel)
  q5p5_pa8=cor(q5p5_pop8@gv[,whichTrait],q5p5_pop8@ebv[,whichTrait])
  q5p5_bestInd9=selectInd(q5p5_pop8, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop9 = randCross(q5p5_bestInd9, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop9 = setEBV(q5p5_pop9,gsModel)
  q5p5_pa9=cor(q5p5_pop9@gv[,whichTrait],q5p5_pop9@ebv[,whichTrait])
  q5p5_bestInd10=selectInd(q5p5_pop9, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop10 = randCross(q5p5_bestInd10, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop10 = setEBV(q5p5_pop10,gsModel)
  q5p5_pa10=cor(q5p5_pop10@gv[,whichTrait],q5p5_pop10@ebv[,whichTrait])
  q5p5_bestInd11=selectInd(q5p5_pop10, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop11 = randCross(q5p5_bestInd11, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop11 = setEBV(q5p5_pop11,gsModel)
  q5p5_pa11=cor(q5p5_pop11@gv[,whichTrait],q5p5_pop11@ebv[,whichTrait])
  q5p5_bestInd12=selectInd(q5p5_pop11, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop12 = randCross(q5p5_bestInd12, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop12 = setEBV(q5p5_pop12,gsModel)
  q5p5_pa12=cor(q5p5_pop12@gv[,whichTrait],q5p5_pop12@ebv[,whichTrait])
  q5p5_bestInd13=selectInd(q5p5_pop12, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop13 = randCross(q5p5_bestInd13, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop13 = setEBV(q5p5_pop13,gsModel)
  q5p5_pa13=cor(q5p5_pop13@gv[,whichTrait],q5p5_pop13@ebv[,whichTrait])
  q5p5_bestInd14=selectInd(q5p5_pop13, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop14 = randCross(q5p5_bestInd14, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop14 = setEBV(q5p5_pop14,gsModel)
  q5p5_pa14=cor(q5p5_pop14@gv[,whichTrait],q5p5_pop14@ebv[,whichTrait])
  q5p5_bestInd15=selectInd(q5p5_pop14, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop15 = randCross(q5p5_bestInd15, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop15 = setEBV(q5p5_pop15,gsModel)
  q5p5_pa15=cor(q5p5_pop15@gv[,whichTrait],q5p5_pop15@ebv[,whichTrait])
  q5p5_bestInd16=selectInd(q5p5_pop15, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop16 = randCross(q5p5_bestInd16, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop16 = setEBV(q5p5_pop16,gsModel)
  q5p5_pa16=cor(q5p5_pop16@gv[,whichTrait],q5p5_pop16@ebv[,whichTrait])
  q5p5_bestInd17=selectInd(q5p5_pop16, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop17 = randCross(q5p5_bestInd17, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop17 = setEBV(q5p5_pop17,gsModel)
  q5p5_pa17=cor(q5p5_pop17@gv[,whichTrait],q5p5_pop17@ebv[,whichTrait])
  q5p5_bestInd18=selectInd(q5p5_pop17, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop18 = randCross(q5p5_bestInd18, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop18 = setEBV(q5p5_pop18,gsModel)
  q5p5_pa18=cor(q5p5_pop18@gv[,whichTrait],q5p5_pop18@ebv[,whichTrait])
  q5p5_bestInd19=selectInd(q5p5_pop18, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop19 = randCross(q5p5_bestInd19, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop19 = setEBV(q5p5_pop19,gsModel)
  q5p5_pa19=cor(q5p5_pop19@gv[,whichTrait],q5p5_pop19@ebv[,whichTrait])
  q5p5_bestInd20=selectInd(q5p5_pop19, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop20 = randCross(q5p5_bestInd20, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop20 = setEBV(q5p5_pop20,gsModel)
  q5p5_pa20=cor(q5p5_pop20@gv[,whichTrait],q5p5_pop20@ebv[,whichTrait])
  q5p5_bestInd21=selectInd(q5p5_pop20, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop21 = randCross(q5p5_bestInd21, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop21 = setEBV(q5p5_pop21,gsModel)
  q5p5_pa21=cor(q5p5_pop21@gv[,whichTrait],q5p5_pop21@ebv[,whichTrait])
  q5p5_bestInd22=selectInd(q5p5_pop21, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop22 = randCross(q5p5_bestInd22, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop22 = setEBV(q5p5_pop22,gsModel)
  q5p5_pa22=cor(q5p5_pop22@gv[,whichTrait],q5p5_pop22@ebv[,whichTrait])
  q5p5_bestInd23=selectInd(q5p5_pop22, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop23 = randCross(q5p5_bestInd23, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop23 = setEBV(q5p5_pop23,gsModel)
  q5p5_pa23=cor(q5p5_pop23@gv[,whichTrait],q5p5_pop23@ebv[,whichTrait])
  q5p5_bestInd24=selectInd(q5p5_pop23, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop24 = randCross(q5p5_bestInd24, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop24 = setEBV(q5p5_pop24,gsModel)
  q5p5_pa24=cor(q5p5_pop24@gv[,whichTrait],q5p5_pop24@ebv[,whichTrait])
  q5p5_bestInd25=selectInd(q5p5_pop24, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop25 = randCross(q5p5_bestInd25, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop25 = setEBV(q5p5_pop25,gsModel)
  q5p5_pa25=cor(q5p5_pop25@gv[,whichTrait],q5p5_pop25@ebv[,whichTrait])
  q5p5_bestInd26=selectInd(q5p5_pop25, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop26 = randCross(q5p5_bestInd26, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop26 = setEBV(q5p5_pop26,gsModel)
  q5p5_pa26=cor(q5p5_pop26@gv[,whichTrait],q5p5_pop26@ebv[,whichTrait])
  q5p5_bestInd27=selectInd(q5p5_pop26, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop27 = randCross(q5p5_bestInd27, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop27 = setEBV(q5p5_pop27,gsModel)
  q5p5_pa27=cor(q5p5_pop27@gv[,whichTrait],q5p5_pop27@ebv[,whichTrait])
  q5p5_bestInd28=selectInd(q5p5_pop27, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop28 = randCross(q5p5_bestInd28, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop28 = setEBV(q5p5_pop28,gsModel)
  q5p5_pa28=cor(q5p5_pop28@gv[,whichTrait],q5p5_pop28@ebv[,whichTrait])
  q5p5_bestInd29=selectInd(q5p5_pop28, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop29 = randCross(q5p5_bestInd29, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop29 = setEBV(q5p5_pop29,gsModel)
  q5p5_pa29=cor(q5p5_pop29@gv[,whichTrait],q5p5_pop29@ebv[,whichTrait])
  q5p5_bestInd30=selectInd(q5p5_pop29, Ne_Par5, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p5_pop30 = randCross(q5p5_bestInd30, nCrosses= Ne_Pop50, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p5_pop30 = setEBV(q5p5_pop30,gsModel)
  q5p5_pa30=cor(q5p5_pop30@gv[,whichTrait],q5p5_pop30@ebv[,whichTrait])
  ###########################################################################################################
  ####### Number of parents = 20 selected to be recombined and create breeding population of 200 ############
  ###########################################################################################################
  q5p20_bestInd1=selectInd(train_pop, Ne_Par20, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop1 = randCross(q5p20_bestInd1, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop1 = setEBV(q5p20_pop1,gsModel)
  q5p20_pa1=cor(q5p20_pop1@gv[,whichTrait],q5p20_pop1@ebv[,whichTrait])
  q5p20_bestInd2=selectInd(q5p20_pop1, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop2 = randCross(q5p20_bestInd2, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop2 = setEBV(q5p20_pop2,gsModel)
  q5p20_pa2=cor(q5p20_pop2@gv[,whichTrait],q5p20_pop2@ebv[,whichTrait])
  q5p20_bestInd3=selectInd(q5p20_pop2, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop3 = randCross(q5p20_bestInd3, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop3 = setEBV(q5p20_pop3,gsModel)
  q5p20_pa3=cor(q5p20_pop3@gv[,whichTrait],q5p20_pop3@ebv[,whichTrait])
  q5p20_bestInd4=selectInd(q5p20_pop3, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop4 = randCross(q5p20_bestInd4, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop4 = setEBV(q5p20_pop4,gsModel)
  q5p20_pa4=cor(q5p20_pop4@gv[,whichTrait],q5p20_pop4@ebv[,whichTrait])
  q5p20_bestInd5=selectInd(q5p20_pop4, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop5 = randCross(q5p20_bestInd5, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop5 = setEBV(q5p20_pop5,gsModel)
  q5p20_pa5=cor(q5p20_pop5@gv[,whichTrait],q5p20_pop5@ebv[,whichTrait])
  q5p20_bestInd6=selectInd(q5p20_pop5, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop6 = randCross(q5p20_bestInd6, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop6 = setEBV(q5p20_pop6,gsModel)
  q5p20_pa6=cor(q5p20_pop6@gv[,whichTrait],q5p20_pop6@ebv[,whichTrait])
  q5p20_bestInd7=selectInd(q5p20_pop6, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop7 = randCross(q5p20_bestInd7, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop7 = setEBV(q5p20_pop7,gsModel)
  q5p20_pa7=cor(q5p20_pop7@gv[,whichTrait],q5p20_pop7@ebv[,whichTrait])
  q5p20_bestInd8 = selectInd(q5p20_pop7, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop8 = randCross(q5p20_bestInd8, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop8 = setEBV(q5p20_pop8,gsModel)
  q5p20_pa8=cor(q5p20_pop8@gv[,whichTrait],q5p20_pop8@ebv[,whichTrait])
  q5p20_bestInd9=selectInd(q5p20_pop8, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop9 = randCross(q5p20_bestInd9, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop9 = setEBV(q5p20_pop9,gsModel)
  q5p20_pa9=cor(q5p20_pop9@gv[,whichTrait],q5p20_pop9@ebv[,whichTrait])
  q5p20_bestInd10=selectInd(q5p20_pop9, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop10 = randCross(q5p20_bestInd10, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop10 = setEBV(q5p20_pop10,gsModel)
  q5p20_pa10=cor(q5p20_pop10@gv[,whichTrait],q5p20_pop10@ebv[,whichTrait])
  q5p20_bestInd11=selectInd(q5p20_pop10, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop11 = randCross(q5p20_bestInd11, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop11 = setEBV(q5p20_pop11,gsModel)
  q5p20_pa11=cor(q5p20_pop11@gv[,whichTrait],q5p20_pop11@ebv[,whichTrait])
  q5p20_bestInd12=selectInd(q5p20_pop11, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop12 = randCross(q5p20_bestInd12, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop12 = setEBV(q5p20_pop12,gsModel)
  q5p20_pa12=cor(q5p20_pop12@gv[,whichTrait],q5p20_pop12@ebv[,whichTrait])
  q5p20_bestInd13=selectInd(q5p20_pop12, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop13 = randCross(q5p20_bestInd13, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop13 = setEBV(q5p20_pop13,gsModel)
  q5p20_pa13=cor(q5p20_pop13@gv[,whichTrait],q5p20_pop13@ebv[,whichTrait])
  q5p20_bestInd14=selectInd(q5p20_pop13, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop14 = randCross(q5p20_bestInd14, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop14 = setEBV(q5p20_pop14,gsModel)
  q5p20_pa14=cor(q5p20_pop14@gv[,whichTrait],q5p20_pop14@ebv[,whichTrait])
  q5p20_bestInd15=selectInd(q5p20_pop14, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop15 = randCross(q5p20_bestInd15, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop15 = setEBV(q5p20_pop15,gsModel)
  q5p20_pa15=cor(q5p20_pop15@gv[,whichTrait],q5p20_pop15@ebv[,whichTrait])
  q5p20_bestInd16=selectInd(q5p20_pop15, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop16 = randCross(q5p20_bestInd16, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop16 = setEBV(q5p20_pop16,gsModel)
  q5p20_pa16=cor(q5p20_pop16@gv[,whichTrait],q5p20_pop16@ebv[,whichTrait])
  q5p20_bestInd17=selectInd(q5p20_pop16, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop17 = randCross(q5p20_bestInd17, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop17 = setEBV(q5p20_pop17,gsModel)
  q5p20_pa17=cor(q5p20_pop17@gv[,whichTrait],q5p20_pop17@ebv[,whichTrait])
  q5p20_bestInd18=selectInd(q5p20_pop17, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop18 = randCross(q5p20_bestInd18, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop18 = setEBV(q5p20_pop18,gsModel)
  q5p20_pa18=cor(q5p20_pop18@gv[,whichTrait],q5p20_pop18@ebv[,whichTrait])
  q5p20_bestInd19=selectInd(q5p20_pop18, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop19 = randCross(q5p20_bestInd19, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop19 = setEBV(q5p20_pop19,gsModel)
  q5p20_pa19=cor(q5p20_pop19@gv[,whichTrait],q5p20_pop19@ebv[,whichTrait])
  q5p20_bestInd20=selectInd(q5p20_pop19, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop20 = randCross(q5p20_bestInd20, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop20 = setEBV(q5p20_pop20,gsModel)
  q5p20_pa20=cor(q5p20_pop20@gv[,whichTrait],q5p20_pop20@ebv[,whichTrait])
  q5p20_bestInd21=selectInd(q5p20_pop20, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop21 = randCross(q5p20_bestInd21, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop21 = setEBV(q5p20_pop21,gsModel)
  q5p20_pa21=cor(q5p20_pop21@gv[,whichTrait],q5p20_pop21@ebv[,whichTrait])
  q5p20_bestInd22=selectInd(q5p20_pop21, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop22 = randCross(q5p20_bestInd22, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop22 = setEBV(q5p20_pop22,gsModel)
  q5p20_pa22=cor(q5p20_pop22@gv[,whichTrait],q5p20_pop22@ebv[,whichTrait])
  q5p20_bestInd23=selectInd(q5p20_pop22, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop23 = randCross(q5p20_bestInd23, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop23 = setEBV(q5p20_pop23,gsModel)
  q5p20_pa23=cor(q5p20_pop23@gv[,whichTrait],q5p20_pop23@ebv[,whichTrait])
  q5p20_bestInd24=selectInd(q5p20_pop23, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop24 = randCross(q5p20_bestInd24, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop24 = setEBV(q5p20_pop24,gsModel)
  q5p20_pa24=cor(q5p20_pop24@gv[,whichTrait],q5p20_pop24@ebv[,whichTrait])
  q5p20_bestInd25=selectInd(q5p20_pop24, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop25 = randCross(q5p20_bestInd25, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop25 = setEBV(q5p20_pop25,gsModel)
  q5p20_pa25=cor(q5p20_pop25@gv[,whichTrait],q5p20_pop25@ebv[,whichTrait])
  q5p20_bestInd26=selectInd(q5p20_pop25, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop26 = randCross(q5p20_bestInd26, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop26 = setEBV(q5p20_pop26,gsModel)
  q5p20_pa26=cor(q5p20_pop26@gv[,whichTrait],q5p20_pop26@ebv[,whichTrait])
  q5p20_bestInd27=selectInd(q5p20_pop26, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop27 = randCross(q5p20_bestInd27, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop27 = setEBV(q5p20_pop27,gsModel)
  q5p20_pa27=cor(q5p20_pop27@gv[,whichTrait],q5p20_pop27@ebv[,whichTrait])
  q5p20_bestInd28=selectInd(q5p20_pop27, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop28 = randCross(q5p20_bestInd28, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop28 = setEBV(q5p20_pop28,gsModel)
  q5p20_pa28=cor(q5p20_pop28@gv[,whichTrait],q5p20_pop28@ebv[,whichTrait])
  q5p20_bestInd29=selectInd(q5p20_pop28, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop29 = randCross(q5p20_bestInd29, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop29 = setEBV(q5p20_pop29,gsModel)
  q5p20_pa29=cor(q5p20_pop29@gv[,whichTrait],q5p20_pop29@ebv[,whichTrait])
  q5p20_bestInd30=selectInd(q5p20_pop29, Ne_Par20, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p20_pop30 = randCross(q5p20_bestInd30, nCrosses= Ne_Pop200, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p20_pop30 = setEBV(q5p20_pop30,gsModel)
  q5p20_pa30=cor(q5p20_pop30@gv[,whichTrait],q5p20_pop30@ebv[,whichTrait])
  ######################################################################################################################
  ####### Number of parents = 100 selected to be recombined and create breeding population of 1000 for GARS ############
  ######################################################################################################################
  q5p100_bestInd1=selectInd(train_pop, Ne_Par100, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop1 = randCross(q5p100_bestInd1, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop1 = setEBV(q5p100_pop1,gsModel)
  q5p100_pa1=cor(q5p100_pop1@gv[,whichTrait],q5p100_pop1@ebv[,whichTrait])
  q5p100_bestInd2=selectInd(q5p100_pop1, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop2 = randCross(q5p100_bestInd2, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop2 = setEBV(q5p100_pop2,gsModel)
  q5p100_pa2=cor(q5p100_pop2@gv[,whichTrait],q5p100_pop2@ebv[,whichTrait])
  q5p100_bestInd3=selectInd(q5p100_pop2, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop3 = randCross(q5p100_bestInd3, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop3 = setEBV(q5p100_pop3,gsModel)
  q5p100_pa3=cor(q5p100_pop3@gv[,whichTrait],q5p100_pop3@ebv[,whichTrait])
  q5p100_bestInd4=selectInd(q5p100_pop3, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop4 = randCross(q5p100_bestInd4, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop4 = setEBV(q5p100_pop4,gsModel)
  q5p100_pa4=cor(q5p100_pop4@gv[,whichTrait],q5p100_pop4@ebv[,whichTrait])
  q5p100_bestInd5=selectInd(q5p100_pop4, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop5 = randCross(q5p100_bestInd5, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop5 = setEBV(q5p100_pop5,gsModel)
  q5p100_pa5=cor(q5p100_pop5@gv[,whichTrait],q5p100_pop5@ebv[,whichTrait])
  q5p100_bestInd6=selectInd(q5p100_pop5, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop6 = randCross(q5p100_bestInd6, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop6 = setEBV(q5p100_pop6,gsModel)
  q5p100_pa6=cor(q5p100_pop6@gv[,whichTrait],q5p100_pop6@ebv[,whichTrait])
  q5p100_bestInd7=selectInd(q5p100_pop6, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop7 = randCross(q5p100_bestInd7, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop7 = setEBV(q5p100_pop7,gsModel)
  q5p100_pa7=cor(q5p100_pop7@gv[,whichTrait],q5p100_pop7@ebv[,whichTrait])
  q5p100_bestInd8=selectInd(q5p100_pop7, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop8 = randCross(q5p100_bestInd8, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop8 = setEBV(q5p100_pop8,gsModel)
  q5p100_pa8=cor(q5p100_pop8@gv[,whichTrait],q5p100_pop8@ebv[,whichTrait])
  q5p100_bestInd9=selectInd(q5p100_pop8, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop9 = randCross(q5p100_bestInd9, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop9 = setEBV(q5p100_pop9,gsModel)
  q5p100_pa9=cor(q5p100_pop9@gv[,whichTrait],q5p100_pop9@ebv[,whichTrait])
  q5p100_bestInd10=selectInd(q5p100_pop9, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop10 = randCross(q5p100_bestInd10, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop10 = setEBV(q5p100_pop10,gsModel)
  q5p100_pa10=cor(q5p100_pop10@gv[,whichTrait],q5p100_pop10@ebv[,whichTrait])
  q5p100_bestInd11=selectInd(q5p100_pop10, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop11 = randCross(q5p100_bestInd11, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop11 = setEBV(q5p100_pop11,gsModel)
  q5p100_pa11=cor(q5p100_pop11@gv[,whichTrait],q5p100_pop11@ebv[,whichTrait])
  q5p100_bestInd12=selectInd(q5p100_pop11, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop12 = randCross(q5p100_bestInd12, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop12 = setEBV(q5p100_pop12,gsModel)
  q5p100_pa12=cor(q5p100_pop12@gv[,whichTrait],q5p100_pop12@ebv[,whichTrait])
  q5p100_bestInd13=selectInd(q5p100_pop12, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop13 = randCross(q5p100_bestInd13, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop13 = setEBV(q5p100_pop13,gsModel)
  q5p100_pa13=cor(q5p100_pop13@gv[,whichTrait],q5p100_pop13@ebv[,whichTrait])
  q5p100_bestInd14=selectInd(q5p100_pop13, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop14 = randCross(q5p100_bestInd14, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop14 = setEBV(q5p100_pop14,gsModel)
  q5p100_pa14=cor(q5p100_pop14@gv[,whichTrait],q5p100_pop14@ebv[,whichTrait])
  q5p100_bestInd15=selectInd(q5p100_pop14, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop15 = randCross(q5p100_bestInd15, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop15 = setEBV(q5p100_pop15,gsModel)
  q5p100_pa15=cor(q5p100_pop15@gv[,whichTrait],q5p100_pop15@ebv[,whichTrait])
  q5p100_bestInd16=selectInd(q5p100_pop15, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop16 = randCross(q5p100_bestInd16, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop16 = setEBV(q5p100_pop16,gsModel)
  q5p100_pa16=cor(q5p100_pop16@gv[,whichTrait],q5p100_pop16@ebv[,whichTrait])
  q5p100_bestInd17=selectInd(q5p100_pop16, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop17 = randCross(q5p100_bestInd17, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop17 = setEBV(q5p100_pop17,gsModel)
  q5p100_pa17=cor(q5p100_pop17@gv[,whichTrait],q5p100_pop17@ebv[,whichTrait])
  q5p100_bestInd18=selectInd(q5p100_pop17, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop18 = randCross(q5p100_bestInd18, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop18 = setEBV(q5p100_pop18,gsModel)
  q5p100_pa18=cor(q5p100_pop18@gv[,whichTrait],q5p100_pop18@ebv[,whichTrait])
  q5p100_bestInd19=selectInd(q5p100_pop18, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop19 = randCross(q5p100_bestInd19, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop19 = setEBV(q5p100_pop19,gsModel)
  q5p100_pa19=cor(q5p100_pop19@gv[,whichTrait],q5p100_pop19@ebv[,whichTrait])
  q5p100_bestInd20=selectInd(q5p100_pop19, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop20 = randCross(q5p100_bestInd20, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop20 = setEBV(q5p100_pop20,gsModel)
  q5p100_pa20=cor(q5p100_pop20@gv[,whichTrait],q5p100_pop20@ebv[,whichTrait])
  q5p100_bestInd21=selectInd(q5p100_pop20, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop21 = randCross(q5p100_bestInd21, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop21 = setEBV(q5p100_pop21,gsModel)
  q5p100_pa21=cor(q5p100_pop21@gv[,whichTrait],q5p100_pop21@ebv[,whichTrait])
  q5p100_bestInd22=selectInd(q5p100_pop21, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop22 = randCross(q5p100_bestInd22, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop22 = setEBV(q5p100_pop22,gsModel)
  q5p100_pa22=cor(q5p100_pop22@gv[,whichTrait],q5p100_pop22@ebv[,whichTrait])
  q5p100_bestInd23=selectInd(q5p100_pop22, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop23 = randCross(q5p100_bestInd23, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop23 = setEBV(q5p100_pop23,gsModel)
  q5p100_pa23=cor(q5p100_pop23@gv[,whichTrait],q5p100_pop23@ebv[,whichTrait])
  q5p100_bestInd24=selectInd(q5p100_pop23, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop24 = randCross(q5p100_bestInd24, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop24 = setEBV(q5p100_pop24,gsModel)
  q5p100_pa24=cor(q5p100_pop24@gv[,whichTrait],q5p100_pop24@ebv[,whichTrait])
  q5p100_bestInd25=selectInd(q5p100_pop24, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop25 = randCross(q5p100_bestInd25, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop25 = setEBV(q5p100_pop25,gsModel)
  q5p100_pa25=cor(q5p100_pop25@gv[,whichTrait],q5p100_pop25@ebv[,whichTrait])
  q5p100_bestInd26=selectInd(q5p100_pop25, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop26 = randCross(q5p100_bestInd26, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop26 = setEBV(q5p100_pop26,gsModel)
  q5p100_pa26=cor(q5p100_pop26@gv[,whichTrait],q5p100_pop26@ebv[,whichTrait])
  q5p100_bestInd27=selectInd(q5p100_pop26, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop27 = randCross(q5p100_bestInd27, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop27 = setEBV(q5p100_pop27,gsModel)
  q5p100_pa27=cor(q5p100_pop27@gv[,whichTrait],q5p100_pop27@ebv[,whichTrait])
  q5p100_bestInd28=selectInd(q5p100_pop27, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop28 = randCross(q5p100_bestInd28, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop28 = setEBV(q5p100_pop28,gsModel)
  q5p100_pa28=cor(q5p100_pop28@gv[,whichTrait],q5p100_pop28@ebv[,whichTrait])
  q5p100_bestInd29=selectInd(q5p100_pop28, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop29 = randCross(q5p100_bestInd29, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop29 = setEBV(q5p100_pop29,gsModel)
  q5p100_pa29=cor(q5p100_pop29@gv[,whichTrait],q5p100_pop29@ebv[,whichTrait])
  q5p100_bestInd30=selectInd(q5p100_pop29, Ne_Par100, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p100_pop30 = randCross(q5p100_bestInd30, nCrosses= Ne_Pop1000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p100_pop30 = setEBV(q5p100_pop30,gsModel)
  q5p100_pa30=cor(q5p100_pop30@gv[,whichTrait],q5p100_pop30@ebv[,whichTrait])
  ######################################################################################################################
  ####### Number of parents = 200 selected to be recombined and create breeding population of 2000 for GARS ############
  ######################################################################################################################
  q5p200_bestInd1=selectInd(train_pop, Ne_Par200, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop1 = randCross(q5p200_bestInd1, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop1 = setEBV(q5p200_pop1,gsModel)
  q5p200_pa1=cor(q5p200_pop1@gv[,whichTrait],q5p200_pop1@ebv[,whichTrait])
  q5p200_bestInd2=selectInd(q5p200_pop1, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop2 = randCross(q5p200_bestInd2, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop2 = setEBV(q5p200_pop2,gsModel)
  q5p200_pa2=cor(q5p200_pop2@gv[,whichTrait],q5p200_pop2@ebv[,whichTrait])
  q5p200_bestInd3=selectInd(q5p200_pop2, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop3 = randCross(q5p200_bestInd3, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop3 = setEBV(q5p200_pop3,gsModel)
  q5p200_pa3=cor(q5p200_pop3@gv[,whichTrait],q5p200_pop3@ebv[,whichTrait])
  q5p200_bestInd4=selectInd(q5p200_pop3, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop4 = randCross(q5p200_bestInd4, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop4 = setEBV(q5p200_pop4,gsModel)
  q5p200_pa4=cor(q5p200_pop4@gv[,whichTrait],q5p200_pop4@ebv[,whichTrait])
  q5p200_bestInd5=selectInd(q5p200_pop4, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop5 = randCross(q5p200_bestInd5, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop5 = setEBV(q5p200_pop5,gsModel)
  q5p200_pa5=cor(q5p200_pop5@gv[,whichTrait],q5p200_pop5@ebv[,whichTrait])
  q5p200_bestInd6=selectInd(q5p200_pop5, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop6 = randCross(q5p200_bestInd6, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop6 = setEBV(q5p200_pop6,gsModel)
  q5p200_pa6=cor(q5p200_pop6@gv[,whichTrait],q5p200_pop6@ebv[,whichTrait])
  q5p200_bestInd7=selectInd(q5p200_pop6, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop7 = randCross(q5p200_bestInd7, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop7 = setEBV(q5p200_pop7,gsModel)
  q5p200_pa7=cor(q5p200_pop7@gv[,whichTrait],q5p200_pop7@ebv[,whichTrait])
  q5p200_bestInd8=selectInd(q5p200_pop7, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop8 = randCross(q5p200_bestInd8, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop8 = setEBV(q5p200_pop8,gsModel)
  q5p200_pa8=cor(q5p200_pop8@gv[,whichTrait],q5p200_pop8@ebv[,whichTrait])
  q5p200_bestInd9=selectInd(q5p200_pop8, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop9 = randCross(q5p200_bestInd9, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop9 = setEBV(q5p200_pop9,gsModel)
  q5p200_pa9=cor(q5p200_pop9@gv[,whichTrait],q5p200_pop9@ebv[,whichTrait])
  q5p200_bestInd10=selectInd(q5p200_pop9, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop10 = randCross(q5p200_bestInd10, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop10 = setEBV(q5p200_pop10,gsModel)
  q5p200_pa10=cor(q5p200_pop10@gv[,whichTrait],q5p200_pop10@ebv[,whichTrait])
  q5p200_bestInd11=selectInd(q5p200_pop10, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop11 = randCross(q5p200_bestInd11, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop11 = setEBV(q5p200_pop11,gsModel)
  q5p200_pa11=cor(q5p200_pop11@gv[,whichTrait],q5p200_pop11@ebv[,whichTrait])
  q5p200_bestInd12=selectInd(q5p200_pop11, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop12 = randCross(q5p200_bestInd12, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop12 = setEBV(q5p200_pop12,gsModel)
  q5p200_pa12=cor(q5p200_pop12@gv[,whichTrait],q5p200_pop12@ebv[,whichTrait])
  q5p200_bestInd13=selectInd(q5p200_pop12, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop13 = randCross(q5p200_bestInd13, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop13 = setEBV(q5p200_pop13,gsModel)
  q5p200_pa13=cor(q5p200_pop13@gv[,whichTrait],q5p200_pop13@ebv[,whichTrait])
  q5p200_bestInd14=selectInd(q5p200_pop13, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop14 = randCross(q5p200_bestInd14, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop14 = setEBV(q5p200_pop14,gsModel)
  q5p200_pa14=cor(q5p200_pop14@gv[,whichTrait],q5p200_pop14@ebv[,whichTrait])
  q5p200_bestInd15=selectInd(q5p200_pop14, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop15 = randCross(q5p200_bestInd15, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop15 = setEBV(q5p200_pop15,gsModel)
  q5p200_pa15=cor(q5p200_pop15@gv[,whichTrait],q5p200_pop15@ebv[,whichTrait])
  q5p200_bestInd16=selectInd(q5p200_pop15, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop16 = randCross(q5p200_bestInd16, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop16 = setEBV(q5p200_pop16,gsModel)
  q5p200_pa16=cor(q5p200_pop16@gv[,whichTrait],q5p200_pop16@ebv[,whichTrait])
  q5p200_bestInd17=selectInd(q5p200_pop16, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop17 = randCross(q5p200_bestInd17, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop17 = setEBV(q5p200_pop17,gsModel)
  q5p200_pa17=cor(q5p200_pop17@gv[,whichTrait],q5p200_pop17@ebv[,whichTrait])
  q5p200_bestInd18=selectInd(q5p200_pop17, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop18 = randCross(q5p200_bestInd18, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop18 = setEBV(q5p200_pop18,gsModel)
  q5p200_pa18=cor(q5p200_pop18@gv[,whichTrait],q5p200_pop18@ebv[,whichTrait])
  q5p200_bestInd19=selectInd(q5p200_pop18, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop19 = randCross(q5p200_bestInd19, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop19 = setEBV(q5p200_pop19,gsModel)
  q5p200_pa19=cor(q5p200_pop19@gv[,whichTrait],q5p200_pop19@ebv[,whichTrait])
  q5p200_bestInd20=selectInd(q5p200_pop19, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop20 = randCross(q5p200_bestInd20, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop20 = setEBV(q5p200_pop20,gsModel)
  q5p200_pa20=cor(q5p200_pop20@gv[,whichTrait],q5p200_pop20@ebv[,whichTrait])
  q5p200_bestInd21=selectInd(q5p200_pop20, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop21 = randCross(q5p200_bestInd21, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop21 = setEBV(q5p200_pop21,gsModel)
  q5p200_pa21=cor(q5p200_pop21@gv[,whichTrait],q5p200_pop21@ebv[,whichTrait])
  q5p200_bestInd22=selectInd(q5p200_pop21, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop22 = randCross(q5p200_bestInd22, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop22 = setEBV(q5p200_pop22,gsModel)
  q5p200_pa22=cor(q5p200_pop22@gv[,whichTrait],q5p200_pop22@ebv[,whichTrait])
  q5p200_bestInd23=selectInd(q5p200_pop22, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop23 = randCross(q5p200_bestInd23, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop23 = setEBV(q5p200_pop23,gsModel)
  q5p200_pa23=cor(q5p200_pop23@gv[,whichTrait],q5p200_pop23@ebv[,whichTrait])
  q5p200_bestInd24=selectInd(q5p200_pop23, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop24 = randCross(q5p200_bestInd24, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop24 = setEBV(q5p200_pop24,gsModel)
  q5p200_pa24=cor(q5p200_pop24@gv[,whichTrait],q5p200_pop24@ebv[,whichTrait])
  q5p200_bestInd25=selectInd(q5p200_pop24, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop25 = randCross(q5p200_bestInd25, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop25 = setEBV(q5p200_pop25,gsModel)
  q5p200_pa25=cor(q5p200_pop25@gv[,whichTrait],q5p200_pop25@ebv[,whichTrait])
  q5p200_bestInd26=selectInd(q5p200_pop25, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop26 = randCross(q5p200_bestInd26, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop26 = setEBV(q5p200_pop26,gsModel)
  q5p200_pa26=cor(q5p200_pop26@gv[,whichTrait],q5p200_pop26@ebv[,whichTrait])
  q5p200_bestInd27=selectInd(q5p200_pop26, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop27 = randCross(q5p200_bestInd27, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop27 = setEBV(q5p200_pop27,gsModel)
  q5p200_pa27=cor(q5p200_pop27@gv[,whichTrait],q5p200_pop27@ebv[,whichTrait])
  q5p200_bestInd28=selectInd(q5p200_pop27, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop28 = randCross(q5p200_bestInd28, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop28 = setEBV(q5p200_pop28,gsModel)
  q5p200_pa28=cor(q5p200_pop28@gv[,whichTrait],q5p200_pop28@ebv[,whichTrait])
  q5p200_bestInd29=selectInd(q5p200_pop28, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop29 = randCross(q5p200_bestInd29, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop29 = setEBV(q5p200_pop29,gsModel)
  q5p200_pa29=cor(q5p200_pop29@gv[,whichTrait],q5p200_pop29@ebv[,whichTrait])
  q5p200_bestInd30=selectInd(q5p200_pop29, Ne_Par200, trait = trait1, use = "ebv", selectTop = TRUE, returnPop = TRUE)
  q5p200_pop30 = randCross(q5p200_bestInd30, nCrosses= Ne_Pop2000, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  q5p200_pop30 = setEBV(q5p200_pop30,gsModel)
  q5p200_pa30=cor(q5p200_pop30@gv[,whichTrait],q5p200_pop30@ebv[,whichTrait])
  
  ######################################################################################################################
  ####### Number of parents = 5 selected to be recombined and create breeding population of 50 for GARS ################
  ######################################################################################################################
  
  train_pop <- setPheno(train_pop,varE = VarE_olig, reps = reps,w=w)
  PRS5_bestInd1=selectInd(train_pop, Ne_Par5_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS5_pop1 = randCross(PRS5_bestInd1, nCrosses= Ne_Pop50_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS5_pop1 = self(PRS5_pop1, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS5_pop1 <- setPheno(PRS5_pop1,varE = VarE_olig, reps = reps,w=w)
  PRS5_pa1=cor(PRS5_pop1@gv[,whichTrait],PRS5_pop1@pheno[,1])
  
  PRS5_bestInd2=selectInd(PRS5_pop1, Ne_Par5_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS5_pop2 = randCross(PRS5_bestInd2, nCrosses= Ne_Pop50_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS5_pop2 = self(PRS5_pop2, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS5_pop2 <- setPheno(PRS5_pop2,varE = VarE_olig, reps = reps,w=w)
  PRS5_pa2=cor(PRS5_pop2@gv[,whichTrait],PRS5_pop2@pheno[,1])
  
  PRS5_bestInd3=selectInd(PRS5_pop2, Ne_Par5_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS5_pop3 = randCross(PRS5_bestInd3, nCrosses= Ne_Pop50_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS5_pop3 = self(PRS5_pop3, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS5_pop3 <- setPheno(PRS5_pop3,varE = VarE_olig, reps = reps,w=w)
  PRS5_pa3=cor(PRS5_pop3@gv[,whichTrait],PRS5_pop3@pheno[,1])
  
  PRS5_bestInd4=selectInd(PRS5_pop3, Ne_Par5_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS5_pop4 = randCross(PRS5_bestInd4, nCrosses= Ne_Pop50_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS5_pop4 = self(PRS5_pop4, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS5_pop4 <- setPheno(PRS5_pop4,varE = VarE_olig, reps = reps,w=w)
  PRS5_pa4=cor(PRS5_pop4@gv[,whichTrait],PRS5_pop4@pheno[,1])
  
  PRS5_bestInd5=selectInd(PRS5_pop4, Ne_Par5_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS5_pop5 = randCross(PRS5_bestInd5, nCrosses= Ne_Pop50_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS5_pop5 = self(PRS5_pop5, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS5_pop5 <- setPheno(PRS5_pop5,varE = VarE_olig, reps = reps,w=w)
  PRS5_pa5=cor(PRS5_pop5@gv[,whichTrait],PRS5_pop5@pheno[,1])
  
  PRS5_bestInd6=selectInd(PRS5_pop5, Ne_Par5_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS5_pop6 = randCross(PRS5_bestInd6, nCrosses= Ne_Pop50_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS5_pop6 = self(PRS5_pop6, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS5_pop6 <- setPheno(PRS5_pop6,varE = VarE_olig, reps = reps,w=w)
  PRS5_pa6=cor(PRS5_pop6@gv[,whichTrait],PRS5_pop6@pheno[,1])
  
  PRS5_bestInd7=selectInd(PRS5_pop6, Ne_Par5_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS5_pop7 = randCross(PRS5_bestInd7, nCrosses= Ne_Pop50_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS5_pop7 = self(PRS5_pop7, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS5_pop7 <- setPheno(PRS5_pop7,varE = VarE_olig, reps = reps,w=w)
  PRS5_pa7=cor(PRS5_pop7@gv[,whichTrait],PRS5_pop7@pheno[,1])
  
  PRS5_bestInd8=selectInd(PRS5_pop7, Ne_Par5_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS5_pop8 = randCross(PRS5_bestInd8, nCrosses= Ne_Pop50_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS5_pop8 = self(PRS5_pop8, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS5_pop8 <- setPheno(PRS5_pop8,varE = VarE_olig, reps = reps,w=w)
  PRS5_pa8=cor(PRS5_pop8@gv[,whichTrait],PRS5_pop8@pheno[,1])
  
  PRS5_bestInd9=selectInd(PRS5_pop8, Ne_Par5_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS5_pop9 = randCross(PRS5_bestInd9, nCrosses= Ne_Pop50_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS5_pop9 = self(PRS5_pop9, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS5_pop9 <- setPheno(PRS5_pop9,varE = VarE_olig, reps = reps,w=w)
  PRS5_pa9=cor(PRS5_pop9@gv[,whichTrait],PRS5_pop9@pheno[,1])
  
  PRS5_bestInd10=selectInd(PRS5_pop9, Ne_Par5_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS5_pop10 = randCross(PRS5_bestInd10, nCrosses= Ne_Pop50_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS5_pop10 = self(PRS5_pop10, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS5_pop10 <- setPheno(PRS5_pop10,varE = VarE_olig, reps = reps,w=w)
  PRS5_pa10=cor(PRS5_pop10@gv[,whichTrait],PRS5_pop10@pheno[,1])
  #####################################################################################
  ######Summary of simulated data #####################################################
  #####################################################################################
  PRS20_bestInd1=selectInd(train_pop, Ne_Par20_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS20_pop1 = randCross(PRS20_bestInd1, nCrosses= Ne_Pop200_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS20_pop1 = self(PRS20_pop1, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS20_pop1 <- setPheno(PRS20_pop1,varE = VarE_olig, reps = reps,w=w)
  PRS20_pa1=cor(PRS20_pop1@gv[,whichTrait],PRS20_pop1@pheno[,1])
  
  PRS20_bestInd2=selectInd(PRS20_pop1, Ne_Par20_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS20_pop2 = randCross(PRS20_bestInd2, nCrosses= Ne_Pop200_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS20_pop2 = self(PRS20_pop2, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS20_pop2 <- setPheno(PRS20_pop2,varE = VarE_olig, reps = reps,w=w)
  PRS20_pa2=cor(PRS20_pop2@gv[,whichTrait],PRS20_pop2@pheno[,1])
  
  PRS20_bestInd3=selectInd(PRS20_pop2, Ne_Par20_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS20_pop3 = randCross(PRS20_bestInd3, nCrosses= Ne_Pop200_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS20_pop3 = self(PRS20_pop3, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS20_pop3 <- setPheno(PRS20_pop3,varE = VarE_olig, reps = reps,w=w)
  PRS20_pa3=cor(PRS20_pop3@gv[,whichTrait],PRS20_pop3@pheno[,1])
  
  PRS20_bestInd4=selectInd(PRS20_pop3, Ne_Par20_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS20_pop4 = randCross(PRS20_bestInd4, nCrosses= Ne_Pop200_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS20_pop4 = self(PRS20_pop4, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS20_pop4 <- setPheno(PRS20_pop4,varE = VarE_olig, reps = reps,w=w)
  PRS20_pa4=cor(PRS20_pop4@gv[,whichTrait],PRS20_pop4@pheno[,1])
  
  PRS20_bestInd5=selectInd(PRS20_pop4, Ne_Par20_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS20_pop5 = randCross(PRS20_bestInd5, nCrosses= Ne_Pop200_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS20_pop5 = self(PRS20_pop5, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS20_pop5 <- setPheno(PRS20_pop5,varE = VarE_olig, reps = reps,w=w)
  PRS20_pa5=cor(PRS20_pop5@gv[,whichTrait],PRS20_pop5@pheno[,1])
  
  PRS20_bestInd6=selectInd(PRS20_pop5, Ne_Par20_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS20_pop6 = randCross(PRS20_bestInd6, nCrosses= Ne_Pop200_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS20_pop6 = self(PRS20_pop6, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS20_pop6 <- setPheno(PRS20_pop6,varE = VarE_olig, reps = reps,w=w)
  PRS20_pa6=cor(PRS20_pop6@gv[,whichTrait],PRS20_pop6@pheno[,1])
  
  PRS20_bestInd7=selectInd(PRS20_pop6, Ne_Par20_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS20_pop7 = randCross(PRS20_bestInd7, nCrosses= Ne_Pop200_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS20_pop7 = self(PRS20_pop7, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS20_pop7 <- setPheno(PRS20_pop7,varE = VarE_olig, reps = reps,w=w)
  PRS20_pa7=cor(PRS20_pop7@gv[,whichTrait],PRS20_pop7@pheno[,1])
  
  PRS20_bestInd8=selectInd(PRS20_pop7, Ne_Par20_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS20_pop8 = randCross(PRS20_bestInd8, nCrosses= Ne_Pop200_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS20_pop8 = self(PRS20_pop8, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS20_pop8 <- setPheno(PRS20_pop8,varE = VarE_olig, reps = reps,w=w)
  PRS20_pa8=cor(PRS20_pop8@gv[,whichTrait],PRS20_pop8@pheno[,1])
  
  PRS20_bestInd9=selectInd(PRS20_pop8, Ne_Par20_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS20_pop9 = randCross(PRS20_bestInd9, nCrosses= Ne_Pop200_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS20_pop9 = self(PRS20_pop9, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS20_pop9 <- setPheno(PRS20_pop9,varE = VarE_olig, reps = reps,w=w)
  PRS20_pa9=cor(PRS20_pop9@gv[,whichTrait],PRS20_pop9@pheno[,1])
  
  PRS20_bestInd10=selectInd(PRS20_pop9, Ne_Par20_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS20_pop10 = randCross(PRS20_bestInd10, nCrosses= Ne_Pop200_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS20_pop10 = self(PRS20_pop10, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS20_pop10 <- setPheno(PRS20_pop10,varE = VarE_olig, reps = reps,w=w)
  PRS20_pa10=cor(PRS20_pop10@gv[,whichTrait],PRS20_pop10@pheno[,1])
  
  ##########################################################################################################################
  ####### Number of parents = 100 selected to be recombined and create breeding population of 1000 for GARS ################
  ##########################################################################################################################
  
  PRS100_bestInd1=selectInd(train_pop, Ne_Par100_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS100_pop1 = randCross(PRS100_bestInd1, nCrosses= Ne_Pop1000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS100_pop1 = self(PRS100_pop1, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS100_pop1 <- setPheno(PRS100_pop1,varE = VarE_olig, reps = reps,w=w)
  PRS100_pa1=cor(PRS100_pop1@gv[,whichTrait],PRS100_pop1@pheno[,1])
  
  PRS100_bestInd2=selectInd(PRS100_pop1, Ne_Par100_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS100_pop2 = randCross(PRS100_bestInd2, nCrosses= Ne_Pop1000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS100_pop2 = self(PRS100_pop2, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS100_pop2 <- setPheno(PRS100_pop2,varE = VarE_olig, reps = reps,w=w)
  PRS100_pa2=cor(PRS100_pop2@gv[,whichTrait],PRS100_pop2@pheno[,1])
  
  PRS100_bestInd3=selectInd(PRS100_pop2, Ne_Par100_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS100_pop3 = randCross(PRS100_bestInd3, nCrosses= Ne_Pop1000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS100_pop3 = self(PRS100_pop3, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS100_pop3 <- setPheno(PRS100_pop3,varE = VarE_olig, reps = reps,w=w)
  PRS100_pa3=cor(PRS100_pop3@gv[,whichTrait],PRS100_pop3@pheno[,1])
  
  PRS100_bestInd4=selectInd(PRS100_pop3, Ne_Par100_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS100_pop4 = randCross(PRS100_bestInd4, nCrosses= Ne_Pop1000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS100_pop4 = self(PRS100_pop4, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS100_pop4 <- setPheno(PRS100_pop4,varE = VarE_olig, reps = reps,w=w)
  PRS100_pa4=cor(PRS100_pop4@gv[,whichTrait],PRS100_pop4@pheno[,1])
  
  PRS100_bestInd5=selectInd(PRS100_pop4, Ne_Par100_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS100_pop5 = randCross(PRS100_bestInd5, nCrosses= Ne_Pop1000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS100_pop5 = self(PRS100_pop5, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS100_pop5 <- setPheno(PRS100_pop5,varE = VarE_olig, reps = reps,w=w)
  PRS100_pa5=cor(PRS100_pop5@gv[,whichTrait],PRS100_pop5@pheno[,1])
  
  PRS100_bestInd6=selectInd(PRS100_pop5, Ne_Par100_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS100_pop6 = randCross(PRS100_bestInd6, nCrosses= Ne_Pop1000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS100_pop6 = self(PRS100_pop6, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS100_pop6 <- setPheno(PRS100_pop6,varE = VarE_olig, reps = reps,w=w)
  PRS100_pa6=cor(PRS100_pop6@gv[,whichTrait],PRS100_pop6@pheno[,1])
  
  PRS100_bestInd7=selectInd(PRS100_pop6, Ne_Par100_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS100_pop7 = randCross(PRS100_bestInd7, nCrosses= Ne_Pop1000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS100_pop7 = self(PRS100_pop7, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS100_pop7 <- setPheno(PRS100_pop7,varE = VarE_olig, reps = reps,w=w)
  PRS100_pa7=cor(PRS100_pop7@gv[,whichTrait],PRS100_pop7@pheno[,1])
  
  PRS100_bestInd8=selectInd(PRS100_pop7, Ne_Par100_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS100_pop8 = randCross(PRS100_bestInd8, nCrosses= Ne_Pop1000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS100_pop8 = self(PRS100_pop8, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS100_pop8 <- setPheno(PRS100_pop8,varE = VarE_olig, reps = reps,w=w)
  PRS100_pa8=cor(PRS100_pop8@gv[,whichTrait],PRS100_pop8@pheno[,1])
  
  PRS100_bestInd9=selectInd(PRS100_pop8, Ne_Par100_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS100_pop9 = randCross(PRS100_bestInd9, nCrosses= Ne_Pop1000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS100_pop9 = self(PRS100_pop9, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS100_pop9 <- setPheno(PRS100_pop9,varE = VarE_olig, reps = reps,w=w)
  PRS100_pa9=cor(PRS100_pop9@gv[,whichTrait],PRS100_pop9@pheno[,1])
  
  PRS100_bestInd10=selectInd(PRS100_pop9, Ne_Par100_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS100_pop10 = randCross(PRS100_bestInd10, nCrosses= Ne_Pop1000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS100_pop10 = self(PRS100_pop10, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS100_pop10 <- setPheno(PRS100_pop10,varE = VarE_olig, reps = reps,w=w)
  PRS100_pa10=cor(PRS100_pop10@gv[,whichTrait],PRS100_pop10@pheno[,1])
  
  ##########################################################################################################################
  ####### Number of parents = 200 selected to be recombined and create breeding population of 2000 for GARS ################
  ##########################################################################################################################
  
  PRS200_bestInd1=selectInd(train_pop, Ne_Par200_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS200_pop1 = randCross(PRS200_bestInd1, nCrosses= Ne_Pop2000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS200_pop1 = self(PRS200_pop1, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS200_pop1 <- setPheno(PRS200_pop1,varE = VarE_olig, reps = reps,w=w)
  PRS200_pa1=cor(PRS200_pop1@gv[,whichTrait],PRS200_pop1@pheno[,1])
  
  PRS200_bestInd2=selectInd(PRS200_pop1, Ne_Par200_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS200_pop2 = randCross(PRS200_bestInd2, nCrosses= Ne_Pop2000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS200_pop2 = self(PRS200_pop2, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS200_pop2 <- setPheno(PRS200_pop2,varE = VarE_olig, reps = reps,w=w)
  PRS200_pa2=cor(PRS200_pop2@gv[,whichTrait],PRS200_pop2@pheno[,1])
  
  PRS200_bestInd3=selectInd(PRS200_pop2, Ne_Par200_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS200_pop3 = randCross(PRS200_bestInd3, nCrosses= Ne_Pop2000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS200_pop3 = self(PRS200_pop3, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS200_pop3 <- setPheno(PRS200_pop3,varE = VarE_olig, reps = reps,w=w)
  PRS200_pa3=cor(PRS200_pop3@gv[,whichTrait],PRS200_pop3@pheno[,1])
  
  PRS200_bestInd4=selectInd(PRS200_pop3, Ne_Par200_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS200_pop4 = randCross(PRS200_bestInd4, nCrosses= Ne_Pop2000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS200_pop4 = self(PRS200_pop4, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS200_pop4 <- setPheno(PRS200_pop4,varE = VarE_olig, reps = reps,w=w)
  PRS200_pa4=cor(PRS200_pop4@gv[,whichTrait],PRS200_pop4@pheno[,1])
  
  PRS200_bestInd5=selectInd(PRS200_pop4, Ne_Par200_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS200_pop5 = randCross(PRS200_bestInd5, nCrosses= Ne_Pop2000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS200_pop5 = self(PRS200_pop5, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS200_pop5 <- setPheno(PRS200_pop5,varE = VarE_olig, reps = reps,w=w)
  PRS200_pa5=cor(PRS200_pop5@gv[,whichTrait],PRS200_pop5@pheno[,1])
  
  PRS200_bestInd6=selectInd(PRS200_pop5, Ne_Par200_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS200_pop6 = randCross(PRS200_bestInd6, nCrosses= Ne_Pop2000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS200_pop6 = self(PRS200_pop6, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS200_pop6 <- setPheno(PRS200_pop6,varE = VarE_olig, reps = reps,w=w)
  PRS200_pa6=cor(PRS200_pop6@gv[,whichTrait],PRS200_pop6@pheno[,1])
  
  PRS200_bestInd7=selectInd(PRS200_pop6, Ne_Par200_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS200_pop7 = randCross(PRS200_bestInd7, nCrosses= Ne_Pop2000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS200_pop7 = self(PRS200_pop7, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS200_pop7 <- setPheno(PRS200_pop7,varE = VarE_olig, reps = reps,w=w)
  PRS200_pa7=cor(PRS200_pop7@gv[,whichTrait],PRS200_pop7@pheno[,1])
  
  PRS200_bestInd8=selectInd(PRS200_pop7, Ne_Par200_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS200_pop8 = randCross(PRS200_bestInd8, nCrosses= Ne_Pop2000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS200_pop8 = self(PRS200_pop8, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS200_pop8 <- setPheno(PRS200_pop8,varE = VarE_olig, reps = reps,w=w)
  PRS200_pa8=cor(PRS200_pop8@gv[,whichTrait],PRS200_pop8@pheno[,1])
  
  PRS200_bestInd9=selectInd(PRS200_pop8, Ne_Par200_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS200_pop9 = randCross(PRS200_bestInd9, nCrosses= Ne_Pop2000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS200_pop9 = self(PRS200_pop9, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS200_pop9 <- setPheno(PRS200_pop9,varE = VarE_olig, reps = reps,w=w)
  PRS200_pa9=cor(PRS200_pop9@gv[,whichTrait],PRS200_pop9@pheno[,1])
  
  PRS200_bestInd10=selectInd(PRS200_pop9, Ne_Par200_pheno, trait = trait1, use = "pheno", selectTop = TRUE, returnPop = TRUE)
  PRS200_pop10 = randCross(PRS200_bestInd10, nCrosses= Ne_Pop2000_pheno, nProgeny = nProgeny, id = NULL, balance = TRUE, parents = NULL, rawPop = FALSE, ignoreGender = FALSE)
  PRS200_pop10 = self(PRS200_pop10, nProgeny = nProgeny, id = NULL, parents = NULL, rawPop = FALSE, simParam = NULL)
  PRS200_pop10 <- setPheno(PRS200_pop10,varE = VarE_olig, reps = reps,w=w)
  PRS200_pa10=cor(PRS200_pop10@gv[,whichTrait],PRS200_pop10@pheno[,1])
  #####################################################################################
  Gen <-c("1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18","19","20","21","22","23","24","25","26","27","28","29","30")
  mean_gv1_q5p5 <- c(mean(q5p5_pop1@gv[,whichTrait]),mean(q5p5_pop2@gv[,whichTrait]),mean(q5p5_pop3@gv[,whichTrait]),mean(q5p5_pop4@gv[,whichTrait]),mean(q5p5_pop5@gv[,whichTrait]),mean(q5p5_pop6@gv[,whichTrait]),mean(q5p5_pop7@gv[,whichTrait]),mean(q5p5_pop8@gv[,whichTrait]),mean(q5p5_pop9@gv[,whichTrait]),mean(q5p5_pop10@gv[,whichTrait]), mean(q5p5_pop11@gv[,whichTrait]),mean(q5p5_pop12@gv[,whichTrait]),mean(q5p5_pop13@gv[,whichTrait]),mean(q5p5_pop14@gv[,whichTrait]),mean(q5p5_pop15@gv[,whichTrait]),mean(q5p5_pop16@gv[,whichTrait]),mean(q5p5_pop17@gv[,whichTrait]),mean(q5p5_pop18@gv[,whichTrait]),mean(q5p5_pop19@gv[,whichTrait]),mean(q5p5_pop20@gv[,whichTrait]), mean(q5p5_pop21@gv[,whichTrait]),mean(q5p5_pop22@gv[,whichTrait]),mean(q5p5_pop23@gv[,whichTrait]),mean(q5p5_pop24@gv[,whichTrait]),mean(q5p5_pop25@gv[,whichTrait]),mean(q5p5_pop26@gv[,whichTrait]),mean(q5p5_pop27@gv[,whichTrait]),mean(q5p5_pop28@gv[,whichTrait]),mean(q5p5_pop29@gv[,whichTrait]),mean(q5p5_pop30@gv[,whichTrait]))
  var_gv1_q5p5 <- c(var(q5p5_pop1@gv[,whichTrait]),var(q5p5_pop2@gv[,whichTrait]),var(q5p5_pop3@gv[,whichTrait]),var(q5p5_pop4@gv[,whichTrait]),var(q5p5_pop5@gv[,whichTrait]),var(q5p5_pop6@gv[,whichTrait]),var(q5p5_pop7@gv[,whichTrait]),var(q5p5_pop8@gv[,whichTrait]),var(q5p5_pop9@gv[,whichTrait]),var(q5p5_pop10@gv[,whichTrait]), var(q5p5_pop11@gv[,whichTrait]),var(q5p5_pop12@gv[,whichTrait]),var(q5p5_pop13@gv[,whichTrait]),var(q5p5_pop14@gv[,whichTrait]),var(q5p5_pop15@gv[,whichTrait]),var(q5p5_pop16@gv[,whichTrait]),var(q5p5_pop17@gv[,whichTrait]),var(q5p5_pop18@gv[,whichTrait]),var(q5p5_pop19@gv[,whichTrait]),var(q5p5_pop20@gv[,whichTrait]), var(q5p5_pop21@gv[,whichTrait]),var(q5p5_pop22@gv[,whichTrait]),var(q5p5_pop23@gv[,whichTrait]),var(q5p5_pop24@gv[,whichTrait]),var(q5p5_pop25@gv[,whichTrait]),var(q5p5_pop26@gv[,whichTrait]),var(q5p5_pop27@gv[,whichTrait]),var(q5p5_pop28@gv[,whichTrait]),var(q5p5_pop29@gv[,whichTrait]),var(q5p5_pop30@gv[,whichTrait]))
  rsqr_q5p5<-c(q5p5_pa1,q5p5_pa2, q5p5_pa3,q5p5_pa4,q5p5_pa5,q5p5_pa6,q5p5_pa7,q5p5_pa8,q5p5_pa9,q5p5_pa10, q5p5_pa11,q5p5_pa12,q5p5_pa13,q5p5_pa14,q5p5_pa15,q5p5_pa16,q5p5_pa17,q5p5_pa18, q5p5_pa19,q5p5_pa20,q5p5_pa21,q5p5_pa22,q5p5_pa23,q5p5_pa24,q5p5_pa25,q5p5_pa26, q5p5_pa27,q5p5_pa28,q5p5_pa29,q5p5_pa30)
  #####################################################################################
  #####################################################################################
  mean_gv1_q5p20 <- c(mean(q5p20_pop1@gv[,whichTrait]),mean(q5p20_pop2@gv[,whichTrait]),mean(q5p20_pop3@gv[,whichTrait]),mean(q5p20_pop4@gv[,whichTrait]),mean(q5p20_pop5@gv[,whichTrait]),mean(q5p20_pop6@gv[,whichTrait]),mean(q5p20_pop7@gv[,whichTrait]),mean(q5p20_pop8@gv[,whichTrait]),mean(q5p20_pop9@gv[,whichTrait]),mean(q5p20_pop10@gv[,whichTrait]), mean(q5p20_pop11@gv[,whichTrait]),mean(q5p20_pop12@gv[,whichTrait]),mean(q5p20_pop13@gv[,whichTrait]),mean(q5p20_pop14@gv[,whichTrait]),mean(q5p20_pop15@gv[,whichTrait]),mean(q5p20_pop16@gv[,whichTrait]),mean(q5p20_pop17@gv[,whichTrait]),mean(q5p20_pop18@gv[,whichTrait]),mean(q5p20_pop19@gv[,whichTrait]),mean(q5p20_pop20@gv[,whichTrait]), mean(q5p20_pop21@gv[,whichTrait]),mean(q5p20_pop22@gv[,whichTrait]),mean(q5p20_pop23@gv[,whichTrait]),mean(q5p20_pop24@gv[,whichTrait]),mean(q5p20_pop25@gv[,whichTrait]),mean(q5p20_pop26@gv[,whichTrait]),mean(q5p20_pop27@gv[,whichTrait]),mean(q5p20_pop28@gv[,whichTrait]),mean(q5p20_pop29@gv[,whichTrait]),mean(q5p20_pop30@gv[,whichTrait]))
  var_gv1_q5p20 <- c(var(q5p20_pop1@gv[,whichTrait]),var(q5p20_pop2@gv[,whichTrait]),var(q5p20_pop3@gv[,whichTrait]),var(q5p20_pop4@gv[,whichTrait]),var(q5p20_pop5@gv[,whichTrait]),var(q5p20_pop6@gv[,whichTrait]),var(q5p20_pop7@gv[,whichTrait]),var(q5p20_pop8@gv[,whichTrait]),var(q5p20_pop9@gv[,whichTrait]),var(q5p20_pop10@gv[,whichTrait]), var(q5p20_pop11@gv[,whichTrait]),var(q5p20_pop12@gv[,whichTrait]),var(q5p20_pop13@gv[,whichTrait]),var(q5p20_pop14@gv[,whichTrait]),var(q5p20_pop15@gv[,whichTrait]),var(q5p20_pop16@gv[,whichTrait]),var(q5p20_pop17@gv[,whichTrait]),var(q5p20_pop18@gv[,whichTrait]),var(q5p20_pop19@gv[,whichTrait]),var(q5p20_pop20@gv[,whichTrait]), var(q5p20_pop21@gv[,whichTrait]),var(q5p20_pop22@gv[,whichTrait]),var(q5p20_pop23@gv[,whichTrait]),var(q5p20_pop24@gv[,whichTrait]),var(q5p20_pop25@gv[,whichTrait]),var(q5p20_pop26@gv[,whichTrait]),var(q5p20_pop27@gv[,whichTrait]),var(q5p20_pop28@gv[,whichTrait]),var(q5p20_pop29@gv[,whichTrait]),var(q5p20_pop30@gv[,whichTrait]))
  rsqr_q5p20<-c(q5p20_pa1,q5p20_pa2, q5p20_pa3,q5p20_pa4,q5p20_pa5,q5p20_pa6,q5p20_pa7,q5p20_pa8,q5p20_pa9,q5p20_pa10, q5p20_pa11,q5p20_pa12,q5p20_pa13,q5p20_pa14,q5p20_pa15,q5p20_pa16,q5p20_pa17,q5p20_pa18, q5p20_pa19,q5p20_pa20,q5p20_pa21,q5p20_pa22,q5p20_pa23,q5p20_pa24,q5p20_pa25,q5p20_pa26, q5p20_pa27,q5p20_pa28,q5p20_pa29,q5p20_pa30)
  #####################################################################################
  #####################################################################################
  mean_gv1_q5p100 <- c(mean(q5p100_pop1@gv[,whichTrait]),mean(q5p100_pop2@gv[,whichTrait]),mean(q5p100_pop3@gv[,whichTrait]),mean(q5p100_pop4@gv[,whichTrait]),mean(q5p100_pop5@gv[,whichTrait]),mean(q5p100_pop6@gv[,whichTrait]),mean(q5p100_pop7@gv[,whichTrait]),mean(q5p100_pop8@gv[,whichTrait]),mean(q5p100_pop9@gv[,whichTrait]),mean(q5p100_pop10@gv[,whichTrait]), mean(q5p100_pop11@gv[,whichTrait]),mean(q5p100_pop12@gv[,whichTrait]),mean(q5p100_pop13@gv[,whichTrait]),mean(q5p100_pop14@gv[,whichTrait]),mean(q5p100_pop15@gv[,whichTrait]),mean(q5p100_pop16@gv[,whichTrait]),mean(q5p100_pop17@gv[,whichTrait]),mean(q5p100_pop18@gv[,whichTrait]),mean(q5p100_pop19@gv[,whichTrait]),mean(q5p100_pop20@gv[,whichTrait]), mean(q5p100_pop21@gv[,whichTrait]),mean(q5p100_pop22@gv[,whichTrait]),mean(q5p100_pop23@gv[,whichTrait]),mean(q5p100_pop24@gv[,whichTrait]),mean(q5p100_pop25@gv[,whichTrait]),mean(q5p100_pop26@gv[,whichTrait]),mean(q5p100_pop27@gv[,whichTrait]),mean(q5p100_pop28@gv[,whichTrait]),mean(q5p100_pop29@gv[,whichTrait]),mean(q5p100_pop30@gv[,whichTrait]))
  var_gv1_q5p100 <- c(var(q5p100_pop1@gv[,whichTrait]),var(q5p100_pop2@gv[,whichTrait]),var(q5p100_pop3@gv[,whichTrait]),var(q5p100_pop4@gv[,whichTrait]),var(q5p100_pop5@gv[,whichTrait]),var(q5p100_pop6@gv[,whichTrait]),var(q5p100_pop7@gv[,whichTrait]),var(q5p100_pop8@gv[,whichTrait]),var(q5p100_pop9@gv[,whichTrait]),var(q5p100_pop10@gv[,whichTrait]), var(q5p100_pop11@gv[,whichTrait]),var(q5p100_pop12@gv[,whichTrait]),var(q5p100_pop13@gv[,whichTrait]),var(q5p100_pop14@gv[,whichTrait]),var(q5p100_pop15@gv[,whichTrait]),var(q5p100_pop16@gv[,whichTrait]),var(q5p100_pop17@gv[,whichTrait]),var(q5p100_pop18@gv[,whichTrait]),var(q5p100_pop19@gv[,whichTrait]),var(q5p100_pop20@gv[,whichTrait]), var(q5p100_pop21@gv[,whichTrait]),var(q5p100_pop22@gv[,whichTrait]),var(q5p100_pop23@gv[,whichTrait]),var(q5p100_pop24@gv[,whichTrait]),var(q5p100_pop25@gv[,whichTrait]),var(q5p100_pop26@gv[,whichTrait]),var(q5p100_pop27@gv[,whichTrait]),var(q5p100_pop28@gv[,whichTrait]),var(q5p100_pop29@gv[,whichTrait]),var(q5p100_pop30@gv[,whichTrait]))
  rsqr_q5p100<-c(q5p100_pa1,q5p100_pa2, q5p100_pa3,q5p100_pa4,q5p100_pa5,q5p100_pa6,q5p100_pa7,q5p100_pa8,q5p100_pa9,q5p100_pa10, q5p100_pa11,q5p100_pa12,q5p100_pa13,q5p100_pa14,q5p100_pa15,q5p100_pa16,q5p100_pa17,q5p100_pa18, q5p100_pa19,q5p100_pa20,q5p100_pa21,q5p100_pa22,q5p100_pa23,q5p100_pa24,q5p100_pa25,q5p100_pa26, q5p100_pa27,q5p100_pa28,q5p100_pa29,q5p100_pa30)
  #####################################################################################
  #####################################################################################
  mean_gv1_q5p200 <- c(mean(q5p200_pop1@gv[,whichTrait]),mean(q5p200_pop2@gv[,whichTrait]),mean(q5p200_pop3@gv[,whichTrait]),mean(q5p200_pop4@gv[,whichTrait]),mean(q5p200_pop5@gv[,whichTrait]),mean(q5p200_pop6@gv[,whichTrait]),mean(q5p200_pop7@gv[,whichTrait]),mean(q5p200_pop8@gv[,whichTrait]),mean(q5p200_pop9@gv[,whichTrait]),mean(q5p200_pop10@gv[,whichTrait]), mean(q5p200_pop11@gv[,whichTrait]),mean(q5p200_pop12@gv[,whichTrait]),mean(q5p200_pop13@gv[,whichTrait]),mean(q5p200_pop14@gv[,whichTrait]),mean(q5p200_pop15@gv[,whichTrait]),mean(q5p200_pop16@gv[,whichTrait]),mean(q5p200_pop17@gv[,whichTrait]),mean(q5p200_pop18@gv[,whichTrait]),mean(q5p200_pop19@gv[,whichTrait]),mean(q5p200_pop20@gv[,whichTrait]), mean(q5p200_pop21@gv[,whichTrait]),mean(q5p200_pop22@gv[,whichTrait]),mean(q5p200_pop23@gv[,whichTrait]),mean(q5p200_pop24@gv[,whichTrait]),mean(q5p200_pop25@gv[,whichTrait]),mean(q5p200_pop26@gv[,whichTrait]),mean(q5p200_pop27@gv[,whichTrait]),mean(q5p200_pop28@gv[,whichTrait]),mean(q5p200_pop29@gv[,whichTrait]),mean(q5p200_pop30@gv[,whichTrait]))
  var_gv1_q5p200 <- c(var(q5p200_pop1@gv[,whichTrait]),var(q5p200_pop2@gv[,whichTrait]),var(q5p200_pop3@gv[,whichTrait]),var(q5p200_pop4@gv[,whichTrait]),var(q5p200_pop5@gv[,whichTrait]),var(q5p200_pop6@gv[,whichTrait]),var(q5p200_pop7@gv[,whichTrait]),var(q5p200_pop8@gv[,whichTrait]),var(q5p200_pop9@gv[,whichTrait]),var(q5p200_pop10@gv[,whichTrait]), var(q5p200_pop11@gv[,whichTrait]),var(q5p200_pop12@gv[,whichTrait]),var(q5p200_pop13@gv[,whichTrait]),var(q5p200_pop14@gv[,whichTrait]),var(q5p200_pop15@gv[,whichTrait]),var(q5p200_pop16@gv[,whichTrait]),var(q5p200_pop17@gv[,whichTrait]),var(q5p200_pop18@gv[,whichTrait]),var(q5p200_pop19@gv[,whichTrait]),var(q5p200_pop20@gv[,whichTrait]), var(q5p200_pop21@gv[,whichTrait]),var(q5p200_pop22@gv[,whichTrait]),var(q5p200_pop23@gv[,whichTrait]),var(q5p200_pop24@gv[,whichTrait]),var(q5p200_pop25@gv[,whichTrait]),var(q5p200_pop26@gv[,whichTrait]),var(q5p200_pop27@gv[,whichTrait]),var(q5p200_pop28@gv[,whichTrait]),var(q5p200_pop29@gv[,whichTrait]),var(q5p200_pop30@gv[,whichTrait]))
  rsqr_q5p200<-c(q5p200_pa1,q5p200_pa2, q5p200_pa3,q5p200_pa4,q5p200_pa5,q5p200_pa6,q5p200_pa7,q5p200_pa8,q5p200_pa9,q5p200_pa10, q5p200_pa11,q5p200_pa12,q5p200_pa13,q5p200_pa14,q5p200_pa15,q5p200_pa16,q5p200_pa17,q5p200_pa18, q5p200_pa19,q5p200_pa20,q5p200_pa21,q5p200_pa22,q5p200_pa23,q5p200_pa24,q5p200_pa25,q5p200_pa26, q5p200_pa27,q5p200_pa28,q5p200_pa29,q5p200_pa30)
  #####################################################################################
  #####################################################################################
  mean_gv1_PRS5 <- c(mean(PRS5_pop1@gv[,whichTrait]),mean(PRS5_pop2@gv[,whichTrait]),mean(PRS5_pop3@gv[,whichTrait]),mean(PRS5_pop4@gv[,whichTrait]),mean(PRS5_pop5@gv[,whichTrait]),mean(PRS5_pop6@gv[,whichTrait]),mean(PRS5_pop7@gv[,whichTrait]),mean(PRS5_pop8@gv[,whichTrait]),mean(PRS5_pop9@gv[,whichTrait]),mean(PRS5_pop10@gv[,whichTrait]),"NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA")
  var_gv1_PRS5 <- c(var(PRS5_pop1@gv[,whichTrait]),var(PRS5_pop2@gv[,whichTrait]),var(PRS5_pop3@gv[,whichTrait]),var(PRS5_pop4@gv[,whichTrait]),var(PRS5_pop5@gv[,whichTrait]),var(PRS5_pop6@gv[,whichTrait]),var(PRS5_pop7@gv[,whichTrait]),var(PRS5_pop8@gv[,whichTrait]),var(PRS5_pop9@gv[,whichTrait]),var(PRS5_pop10@gv[,whichTrait]),"NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA")
  rsqr_PRS5<-c(PRS5_pa1,PRS5_pa2, PRS5_pa3,PRS5_pa4,PRS5_pa5,PRS5_pa6,PRS5_pa7,PRS5_pa8,PRS5_pa9,PRS5_pa10,"NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA")
  #####################################################################################
  #####################################################################################
  mean_gv1_PRS20 <- c(mean(PRS20_pop1@gv[,whichTrait]),mean(PRS20_pop2@gv[,whichTrait]),mean(PRS20_pop3@gv[,whichTrait]),mean(PRS20_pop4@gv[,whichTrait]),mean(PRS20_pop5@gv[,whichTrait]),mean(PRS20_pop6@gv[,whichTrait]),mean(PRS20_pop7@gv[,whichTrait]),mean(PRS20_pop8@gv[,whichTrait]),mean(PRS20_pop9@gv[,whichTrait]),mean(PRS20_pop10@gv[,whichTrait]),"NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA")
  var_gv1_PRS20 <- c(var(PRS20_pop1@gv[,whichTrait]),var(PRS20_pop2@gv[,whichTrait]),var(PRS20_pop3@gv[,whichTrait]),var(PRS20_pop4@gv[,whichTrait]),var(PRS20_pop5@gv[,whichTrait]),var(PRS20_pop6@gv[,whichTrait]),var(PRS20_pop7@gv[,whichTrait]),var(PRS20_pop8@gv[,whichTrait]),var(PRS20_pop9@gv[,whichTrait]),var(PRS20_pop10@gv[,whichTrait]),"NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA")
  rsqr_PRS20<-c(PRS20_pa1,PRS20_pa2, PRS20_pa3,PRS20_pa4,PRS20_pa5,PRS20_pa6,PRS20_pa7,PRS20_pa8,PRS20_pa9,PRS20_pa10,"NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA")
  #####################################################################################
  #####################################################################################
  mean_gv1_PRS100 <- c(mean(PRS100_pop1@gv[,whichTrait]),mean(PRS100_pop2@gv[,whichTrait]),mean(PRS100_pop3@gv[,whichTrait]),mean(PRS100_pop4@gv[,whichTrait]),mean(PRS100_pop5@gv[,whichTrait]),mean(PRS100_pop6@gv[,whichTrait]),mean(PRS100_pop7@gv[,whichTrait]),mean(PRS100_pop8@gv[,whichTrait]),mean(PRS100_pop9@gv[,whichTrait]),mean(PRS100_pop10@gv[,whichTrait]),"NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA")
  var_gv1_PRS100 <- c(var(PRS100_pop1@gv[,whichTrait]),var(PRS100_pop2@gv[,whichTrait]),var(PRS100_pop3@gv[,whichTrait]),var(PRS100_pop4@gv[,whichTrait]),var(PRS100_pop5@gv[,whichTrait]),var(PRS100_pop6@gv[,whichTrait]),var(PRS100_pop7@gv[,whichTrait]),var(PRS100_pop8@gv[,whichTrait]),var(PRS100_pop9@gv[,whichTrait]),var(PRS100_pop10@gv[,whichTrait]),"NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA")
  rsqr_PRS100<-c(PRS100_pa1,PRS100_pa2, PRS100_pa3,PRS100_pa4,PRS100_pa5,PRS100_pa6,PRS100_pa7,PRS100_pa8,PRS100_pa9,PRS100_pa10,"NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA")
  #####################################################################################
  #####################################################################################
  mean_gv1_PRS200 <- c(mean(PRS200_pop1@gv[,whichTrait]),mean(PRS200_pop2@gv[,whichTrait]),mean(PRS200_pop3@gv[,whichTrait]),mean(PRS200_pop4@gv[,whichTrait]),mean(PRS200_pop5@gv[,whichTrait]),mean(PRS200_pop6@gv[,whichTrait]),mean(PRS200_pop7@gv[,whichTrait]),mean(PRS200_pop8@gv[,whichTrait]),mean(PRS200_pop9@gv[,whichTrait]),mean(PRS200_pop10@gv[,whichTrait]),"NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA")
  var_gv1_PRS200 <- c(var(PRS200_pop1@gv[,whichTrait]),var(PRS200_pop2@gv[,whichTrait]),var(PRS200_pop3@gv[,whichTrait]),var(PRS200_pop4@gv[,whichTrait]),var(PRS200_pop5@gv[,whichTrait]),var(PRS200_pop6@gv[,whichTrait]),var(PRS200_pop7@gv[,whichTrait]),var(PRS200_pop8@gv[,whichTrait]),var(PRS200_pop9@gv[,whichTrait]),var(PRS200_pop10@gv[,whichTrait]),"NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA")
  rsqr_PRS200<-c(PRS200_pa1,PRS200_pa2, PRS200_pa3,PRS200_pa4,PRS200_pa5,PRS200_pa6,PRS200_pa7,PRS200_pa8,PRS200_pa9,PRS200_pa10,"NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA", "NA","NA","NA","NA","NA")
  #####################################################################################
  res_mat <- data.frame(Gen,mean_gv1_q5p5,var_gv1_q5p5,rsqr_q5p5,mean_gv1_q5p20,var_gv1_q5p20,rsqr_q5p20,mean_gv1_q5p100,var_gv1_q5p100,rsqr_q5p100,mean_gv1_q5p200,var_gv1_q5p200, rsqr_q5p200, mean_gv1_PRS5,var_gv1_PRS5, rsqr_PRS5,mean_gv1_PRS20,var_gv1_PRS20, rsqr_PRS20,mean_gv1_PRS100,var_gv1_PRS100,rsqr_PRS100,mean_gv1_PRS200,var_gv1_PRS200,rsqr_PRS200)
  df_mat <- rbind(df_mat, res_mat)
}
df_mat
write.csv(df_mat, file = "GS_Q50_ALL_Par200Pop2000.csv")

